Package: weatherMRJD
Title: Weather Analysis and Markov Regime Switching Jump Diffusion
        Models
Version: 0.1.1
Authors@R: 
    person("Okechukwu J.", "Obulezi", 
           email = "oj.obulezi@unizik.edu.ng", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7753-1868"))
Description: Provides statistical tools for analyzing weather patterns, temperature 
    anomalies, and climate risk. Implements Markov regime-switching jump diffusion (MRJD) 
    models to capture abrupt shifts, extreme weather events, and structural breaks in 
    environmental time series data. Estimates model parameters using maximum likelihood 
    estimation and offers utility functions for simulating regime-dependent stochastic 
    processes. The regime-switching methodology is based on Hamilton (1989) "Analysis of 
    Time Series Subject to Changes in Regime" <doi:10.2307/1912559>.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: stats
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-19 16:35:46 UTC; Dr. O. J. Obulezi
Author: Okechukwu J. Obulezi [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7753-1868>)
Maintainer: Okechukwu J. Obulezi <oj.obulezi@unizik.edu.ng>
Repository: CRAN
Date/Publication: 2026-08-20 15:20:02 UTC
